Auto-sync with upstream master.

This commit is contained in:
Carlos O'Donell 2016-04-29 23:08:42 -04:00
parent cfdb093a22
commit fe4ad2a06e
9 changed files with 75 additions and 112 deletions

View File

@ -137,6 +137,7 @@ en_HK/ISO-8859-1 \
en_IE.UTF-8/UTF-8 \ en_IE.UTF-8/UTF-8 \
en_IE/ISO-8859-1 \ en_IE/ISO-8859-1 \
en_IE@euro/ISO-8859-15 \ en_IE@euro/ISO-8859-15 \
en_IL/UTF-8 \
en_IN/UTF-8 \ en_IN/UTF-8 \
en_NG/UTF-8 \ en_NG/UTF-8 \
en_NZ.UTF-8/UTF-8 \ en_NZ.UTF-8/UTF-8 \
@ -294,6 +295,7 @@ lg_UG/ISO-8859-10 \
li_BE/UTF-8 \ li_BE/UTF-8 \
li_NL/UTF-8 \ li_NL/UTF-8 \
lij_IT/UTF-8 \ lij_IT/UTF-8 \
ln_CD/UTF-8 \
lo_LA/UTF-8 \ lo_LA/UTF-8 \
lt_LT.UTF-8/UTF-8 \ lt_LT.UTF-8/UTF-8 \
lt_LT/ISO-8859-13 \ lt_LT/ISO-8859-13 \

View File

@ -1,41 +0,0 @@
diff --git a/Makefile.in b/Makefile.in
index 710ce7e..3fe9e73 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -12,7 +12,7 @@ install:
LC_ALL=C; export LC_ALL; \
$(MAKE) -r PARALLELMFLAGS="$(PARALLELMFLAGS)" -C $(srcdir) objdir=`pwd` $@
-bench bench-clean:
+bench bench-clean bench-build:
$(MAKE) -C $(srcdir)/benchtests $(PARALLELMFLAGS) objdir=`pwd` $@
# Convenience target to rebuild ULPs for all math tests.
diff --git a/Rules b/Rules
index 4f9cdf3..42d0368 100644
--- a/Rules
+++ b/Rules
@@ -83,7 +83,7 @@ common-generated += dummy.o dummy.c
# This makes all the auxiliary and test programs.
-.PHONY: others tests bench
+.PHONY: others tests bench bench-build
ifeq ($(build-programs),yes)
others: $(addprefix $(objpfx),$(others) $(sysdep-others) $(extra-objs))
diff --git a/benchtests/Makefile b/benchtests/Makefile
index fd3036d..7cbceaa 100644
--- a/benchtests/Makefile
+++ b/benchtests/Makefile
@@ -103,6 +103,10 @@ bench-clean:
bench: $(timing-type) $(gen-locales) bench-set bench-func bench-malloc
+bench-build: bench-set-build bench-func-build
+bench-set-build: $(binaries-benchset)
+bench-func-build: $(binaries-bench) $(binaries-bench-malloc)
+
bench-set: $(binaries-benchset)
for run in $^; do \
echo "Running $${run}"; \

View File

@ -44,18 +44,18 @@ index 0000000..fdf460e
+revision "1.0" +revision "1.0"
+date "2015-08-10" +date "2015-08-10"
+% +%
+category "C:2015";LC_IDENTIFICATION +category "i18n:2012";LC_IDENTIFICATION
+category "C:2015";LC_CTYPE +category "i18n:2012";LC_CTYPE
+category "C:2015";LC_COLLATE +category "i18n:2012";LC_COLLATE
+category "C:2015";LC_TIME +category "i18n:2012";LC_TIME
+category "C:2015";LC_NUMERIC +category "i18n:2012";LC_NUMERIC
+category "C:2015";LC_MONETARY +category "i18n:2012";LC_MONETARY
+category "C:2015";LC_MESSAGES +category "i18n:2012";LC_MESSAGES
+category "C:2015";LC_PAPER +category "i18n:2012";LC_PAPER
+category "C:2015";LC_NAME +category "i18n:2012";LC_NAME
+category "C:2015";LC_ADDRESS +category "i18n:2012";LC_ADDRESS
+category "C:2015";LC_TELEPHONE +category "i18n:2012";LC_TELEPHONE
+category "C:2015";LC_MEASUREMENT +category "i18n:2012";LC_MEASUREMENT
+END LC_IDENTIFICATION +END LC_IDENTIFICATION
+ +
+LC_CTYPE +LC_CTYPE

View File

@ -1,16 +1,16 @@
Index: glibc-2.22-193-g315267a/resolv/nss_dns/dns-host.c Index: glibc-2.23-276-gb65b205/resolv/nss_dns/dns-host.c
=================================================================== ===================================================================
--- glibc-2.22-193-g315267a.orig/resolv/nss_dns/dns-host.c --- glibc-2.23-276-gb65b205.orig/resolv/nss_dns/dns-host.c
+++ glibc-2.22-193-g315267a/resolv/nss_dns/dns-host.c +++ glibc-2.23-276-gb65b205/resolv/nss_dns/dns-host.c
@@ -79,6 +79,7 @@ @@ -78,6 +78,7 @@
#include <stdlib.h>
#include <stddef.h> #include <stddef.h>
#include <string.h> #include <string.h>
#include <sys/syslog.h>
+#include <libc-internal.h> +#include <libc-internal.h>
#include "nsswitch.h" #include "nsswitch.h"
@@ -561,10 +562,19 @@ addrsort (char **ap, int num) @@ -566,10 +567,19 @@ addrsort (char **ap, int num)
num = MAX_NR_ADDRS; num = MAX_NR_ADDRS;
for (i = 0; i < num; i++, p++) for (i = 0; i < num; i++, p++)
{ {

View File

@ -1,16 +1,16 @@
Index: glibc-2.22-193-g315267a/resolv/gethnamaddr.c Index: glibc-2.23-276-gb65b205/resolv/gethnamaddr.c
=================================================================== ===================================================================
--- glibc-2.22-193-g315267a.orig/resolv/gethnamaddr.c --- glibc-2.23-276-gb65b205.orig/resolv/gethnamaddr.c
+++ glibc-2.22-193-g315267a/resolv/gethnamaddr.c +++ glibc-2.23-276-gb65b205/resolv/gethnamaddr.c
@@ -71,6 +71,7 @@ static char sccsid[] = "@(#)gethostnamad @@ -68,6 +68,7 @@
#include <ctype.h>
#include <errno.h> #include <errno.h>
#include <syslog.h> #include <stdlib.h>
#include <string.h>
+#include <libc-internal.h> +#include <libc-internal.h>
#define RESOLVSORT #define MAXALIASES 35
#define MAXADDRS 35
@@ -986,10 +987,19 @@ addrsort(ap, num) @@ -864,10 +865,19 @@ addrsort (char **ap, int num)
p = ap; p = ap;
for (i = 0; i < num; i++, p++) { for (i = 0; i < num; i++, p++) {

View File

@ -12,24 +12,22 @@ Date: Thu Feb 19 15:52:08 2015 +0100
setting nsaddr_list[].sin_family to zero. setting nsaddr_list[].sin_family to zero.
reverted: reverted:
Index: glibc-2.23-131-ga603305/resolv/res_send.c Index: glibc-2.23-276-gb65b205/resolv/res_send.c
=================================================================== ===================================================================
--- glibc-2.23-131-ga603305.orig/resolv/res_send.c --- glibc-2.23-276-gb65b205.orig/resolv/res_send.c
+++ glibc-2.23-131-ga603305/resolv/res_send.c +++ glibc-2.23-276-gb65b205/resolv/res_send.c
@@ -193,7 +193,6 @@ evNowTime(struct timespec *res) { @@ -188,7 +188,6 @@ evNowTime(struct timespec *res) {
/* Forward. */ /* Forward. */
@ -126,7 +122,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
static int send_vc(res_state, const u_char *, int, static int send_vc(res_state, const u_char *, int,
const u_char *, int, const u_char *, int,
u_char **, int *, int *, int, u_char **, u_char **, int *, int *, int, u_char **,
@@ -231,21 +230,20 @@ res_ourserver_p(const res_state statp, c @@ -226,21 +225,20 @@ res_ourserver_p(const res_state statp, c
in_port_t port = in4p->sin_port; in_port_t port = in4p->sin_port;
in_addr_t addr = in4p->sin_addr.s_addr; in_addr_t addr = in4p->sin_addr.s_addr;
@ -154,7 +150,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
(srv->sin6_port == inp->sin6_port) && (srv->sin6_port == inp->sin6_port) &&
!(memcmp(&srv->sin6_addr, &in6addr_any, !(memcmp(&srv->sin6_addr, &in6addr_any,
sizeof (struct in6_addr)) && sizeof (struct in6_addr)) &&
@@ -397,48 +395,80 @@ __libc_res_nsend(res_state statp, const @@ -392,48 +390,80 @@ __libc_res_nsend(res_state statp, const
* If the ns_addr_list in the resolver context has changed, then * If the ns_addr_list in the resolver context has changed, then
* invalidate our cached copy and the associated timing data. * invalidate our cached copy and the associated timing data.
*/ */
@ -252,7 +248,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
} }
/* /*
@@ -447,37 +477,44 @@ __libc_res_nsend(res_state statp, const @@ -442,37 +472,44 @@ __libc_res_nsend(res_state statp, const
*/ */
if (__builtin_expect ((statp->options & RES_ROTATE) != 0, 0) && if (__builtin_expect ((statp->options & RES_ROTATE) != 0, 0) &&
(statp->options & RES_BLAST) == 0) { (statp->options & RES_BLAST) == 0) {
@ -317,7 +313,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
same_ns: same_ns:
#ifdef USE_HOOKS #ifdef USE_HOOKS
if (__glibc_unlikely (statp->qhook != NULL)) { if (__glibc_unlikely (statp->qhook != NULL)) {
@@ -634,21 +671,6 @@ libresolv_hidden_def (res_nsend) @@ -629,21 +666,6 @@ libresolv_hidden_def (res_nsend)
/* Private */ /* Private */
@ -339,7 +335,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
/* Close the resolver structure, assign zero to *RESPLEN2 if RESPLEN2 /* Close the resolver structure, assign zero to *RESPLEN2 if RESPLEN2
is not NULL, and return zero. */ is not NULL, and return zero. */
static int static int
@@ -742,7 +764,7 @@ send_vc(res_state statp, @@ -737,7 +759,7 @@ send_vc(res_state statp,
const HEADER *hp = (HEADER *) buf; const HEADER *hp = (HEADER *) buf;
const HEADER *hp2 = (HEADER *) buf2; const HEADER *hp2 = (HEADER *) buf2;
HEADER *anhp = (HEADER *) *ansp; HEADER *anhp = (HEADER *) *ansp;
@ -348,7 +344,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
int truncating, connreset, n; int truncating, connreset, n;
/* On some architectures compiler might emit a warning indicating /* On some architectures compiler might emit a warning indicating
'resplen' may be used uninitialized. However if buf2 == NULL 'resplen' may be used uninitialized. However if buf2 == NULL
@@ -775,8 +797,8 @@ send_vc(res_state statp, @@ -768,8 +790,8 @@ send_vc(res_state statp,
if (getpeername(statp->_vcsock, if (getpeername(statp->_vcsock,
(struct sockaddr *)&peer, &size) < 0 || (struct sockaddr *)&peer, &size) < 0 ||
@ -359,7 +355,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
statp->_flags &= ~RES_F_VC; statp->_flags &= ~RES_F_VC;
} }
} }
@@ -785,19 +807,20 @@ send_vc(res_state statp, @@ -778,7 +800,7 @@ send_vc(res_state statp,
if (statp->_vcsock >= 0) if (statp->_vcsock >= 0)
__res_iclose(statp, false); __res_iclose(statp, false);
@ -368,6 +364,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
if (statp->_vcsock < 0) { if (statp->_vcsock < 0) {
*terrno = errno; *terrno = errno;
Perror(statp, stderr, "socket(vc)", errno); Perror(statp, stderr, "socket(vc)", errno);
@@ -787,12 +809,13 @@ send_vc(res_state statp,
return (-1); return (-1);
} }
__set_errno (0); __set_errno (0);
@ -381,10 +378,10 @@ Index: glibc-2.23-131-ga603305/resolv/res_send.c
- Aerror(statp, stderr, "connect/vc", errno, nsap); - Aerror(statp, stderr, "connect/vc", errno, nsap);
+ Aerror(statp, stderr, "connect/vc", errno, + Aerror(statp, stderr, "connect/vc", errno,
+ (struct sockaddr *) nsap); + (struct sockaddr *) nsap);
__res_iclose(statp, false); return close_and_return_error (statp, resplen2);
return (0);
} }
@@ -991,7 +1014,8 @@ static int statp->_flags |= RES_F_VC;
@@ -983,7 +1006,8 @@ static int
reopen (res_state statp, int *terrno, int ns) reopen (res_state statp, int *terrno, int ns)
{ {
if (EXT(statp).nssocks[ns] == -1) { if (EXT(statp).nssocks[ns] == -1) {

View File

@ -1,6 +1,6 @@
%define glibcsrcdir glibc-2.23-193-g41e77f3 %define glibcsrcdir glibc-2.23-276-gb65b205
%define glibcversion 2.23.90 %define glibcversion 2.23.90
%define glibcrelease 12%{?dist} %define glibcrelease 13%{?dist}
# Pre-release tarballs are pulled in from git using a command that is # Pre-release tarballs are pulled in from git using a command that is
# effectively: # effectively:
# #
@ -301,13 +301,6 @@ Patch2037: glibc-rh1315108.patch
# Upstream BZ 19573, patch reverts problematic commit # Upstream BZ 19573, patch reverts problematic commit
Patch2099: glibc-rh1252570.patch Patch2099: glibc-rh1252570.patch
##############################################################################
#
# Benchmark comparison patches.
#
##############################################################################
Patch3002: glibc-bench-build.patch
############################################################################## ##############################################################################
# End of glibc patches. # End of glibc patches.
############################################################################## ##############################################################################
@ -777,7 +770,6 @@ microbenchmark tests on the system.
%patch2034 -p1 %patch2034 -p1
%patch0052 -p1 %patch0052 -p1
%patch0053 -p1 %patch0053 -p1
%patch3002 -p1
%patch0054 -p1 %patch0054 -p1
%patch0055 -p1 %patch0055 -p1
%patch0056 -p1 %patch0056 -p1
@ -2091,6 +2083,9 @@ rm -f *.filelist*
%endif %endif
%changelog %changelog
* Fri Apr 29 2016 Carlos O'Donell <carlos@systemhalted.org> - 2.23.90-13
- Auto-sync with upstream master.
* Thu Apr 28 2016 Carlos O'Donell <carlos@redhat.com> - 2.23.90-12 * Thu Apr 28 2016 Carlos O'Donell <carlos@redhat.com> - 2.23.90-12
- Move spec file system information logging to the build stage. - Move spec file system information logging to the build stage.

View File

@ -1 +1 @@
ff0b0186a2774f36e1b68620bec04733 glibc-2.23-193-g41e77f3.tar.gz 91fda2dd096d8dd9262097176281a35f glibc-2.23-276-gb65b205.tar.gz

View File

@ -92,11 +92,20 @@ perl -pi \
s/^(%changelog)$/\$1\n$changelog/" \ s/^(%changelog)$/\$1\n$changelog/" \
glibc.spec glibc.spec
function print_steps {
echo "+ (a) Updating sources e.g. fedpkg new-sources $srcdir.tar.gz"
echo "+ (b) Committing changes e.g. git commit -a"
echo "+ (c) Pushing to fedora e.g. fedpkg push"
echo "+ (d) Building fedora branch e.g. fedpkg build"
}
function prep_failed { function prep_failed {
# fedpkg prep failed. # fedpkg prep failed.
if [ $? -ne 0 ]; then if [ $? -ne 0 ]; then
echo "+ Source prep failed." echo "+ Source prep failed."
echo "+ Check the output in $tmpfile and fix things before committing." echo "+ The 'sources' file is unmodified. Manually use $srcdir.tar.gz."
echo "+ Check the output in $tmpfile and fix things before:"
print_steps
false false
fi fi
} }
@ -129,5 +138,6 @@ if [ $branch == "master" ]; then
else else
echo "+ This is a non-development branch." echo "+ This is a non-development branch."
echo "+ Please review the results of the sync." echo "+ Please review the results of the sync."
echo "+ Once reviewed you need to commit, push, and build." echo "+ Once reviewed you need to:"
print_steps
fi fi
Index: glibc-2.23-131-ga603305/resolv/res_init.c Index: glibc-2.23-276-gb65b205/resolv/res_init.c
=================================================================== ===================================================================
--- glibc-2.23-131-ga603305.orig/resolv/res_init.c --- glibc-2.23-276-gb65b205.orig/resolv/res_init.c
+++ glibc-2.23-131-ga603305/resolv/res_init.c +++ glibc-2.23-276-gb65b205/resolv/res_init.c
@@ -139,8 +139,10 @@ __res_vinit(res_state statp, int preinit @@ -122,8 +122,8 @@ __res_vinit(res_state statp, int preinit
char *cp, **pp; char *cp, **pp;
int n; int n;
char buf[BUFSIZ]; char buf[BUFSIZ];
- int nserv = 0; /* number of nameservers read from file */ - int nserv = 0; /* number of nameservers read from file */
- int have_serv6 = 0; - int have_serv6 = 0;
+ int nserv = 0; /* number of IPv4 nameservers read from file */ + int nserv = 0; /* number of IPv4 nameservers read from file */
+#ifdef _LIBC
+ int nservall = 0; /* number of (IPv4 + IPV6) nameservers read from file */ + int nservall = 0; /* number of (IPv4 + IPV6) nameservers read from file */
+#endif
int haveenv = 0; int haveenv = 0;
int havesearch = 0; int havesearch = 0;
#ifdef RESOLVSORT int nsort = 0;
@@ -169,9 +171,15 @@ __res_vinit(res_state statp, int preinit @@ -145,9 +145,15 @@ __res_vinit(res_state statp, int preinit
statp->_flags = 0; statp->_flags = 0;
statp->qhook = NULL; statp->qhook = NULL;
statp->rhook = NULL; statp->rhook = NULL;
@ -47,7 +45,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_init.c
/* Allow user to override the local domain definition */ /* Allow user to override the local domain definition */
if ((cp = getenv("LOCALDOMAIN")) != NULL) { if ((cp = getenv("LOCALDOMAIN")) != NULL) {
@@ -275,7 +283,11 @@ __res_vinit(res_state statp, int preinit @@ -251,7 +257,11 @@ __res_vinit(res_state statp, int preinit
continue; continue;
} }
/* read nameservers to query */ /* read nameservers to query */
@ -59,7 +57,7 @@ Index: glibc-2.23-131-ga603305/resolv/res_init.c
struct in_addr a; struct in_addr a;
cp = buf + sizeof("nameserver") - 1; cp = buf + sizeof("nameserver") - 1;
@@ -283,12 +295,13 @@ __res_vinit(res_state statp, int preinit @@ -259,11 +269,12 @@ __res_vinit(res_state statp, int preinit
cp++; cp++;
if ((*cp != '\0') && (*cp != '\n') if ((*cp != '\0') && (*cp != '\n')
&& __inet_aton(cp, &a)) { && __inet_aton(cp, &a)) {
@ -71,12 +69,11 @@ Index: glibc-2.23-131-ga603305/resolv/res_init.c
+ statp->nsaddr_list[nservall].sin_port = + statp->nsaddr_list[nservall].sin_port =
htons(NAMESERVER_PORT); htons(NAMESERVER_PORT);
nserv++; nserv++;
#ifdef _LIBC
+ nservall++; + nservall++;
} else { } else {
struct in6_addr a6; struct in6_addr a6;
char *el; char *el;
@@ -330,11 +343,10 @@ __res_vinit(res_state statp, int preinit @@ -305,11 +316,10 @@ __res_vinit(res_state statp, int preinit
} }
} }
@ -91,21 +88,20 @@ Index: glibc-2.23-131-ga603305/resolv/res_init.c
+ nservall++; + nservall++;
} }
} }
#endif }
@@ -389,9 +401,10 @@ __res_vinit(res_state statp, int preinit @@ -361,8 +371,9 @@ __res_vinit(res_state statp, int preinit
continue; continue;
} }
} }
- statp->nscount = nserv; - statp->nscount = nserv;
+ statp->nscount = nservall;
#ifdef _LIBC
- if (have_serv6) { - if (have_serv6) {
+ statp->nscount = nservall;
+ if (nservall - nserv > 0) { + if (nservall - nserv > 0) {
+ statp->_u._ext.nscount6 = nservall - nserv; + statp->_u._ext.nscount6 = nservall - nserv;
/* We try IPv6 servers again. */ /* We try IPv6 servers again. */
statp->ipv6_unavail = false; statp->ipv6_unavail = false;
} }
@@ -591,6 +604,8 @@ __res_iclose(res_state statp, bool free_ @@ -532,6 +543,8 @@ __res_iclose(res_state statp, bool free_
statp->_u._ext.nsaddrs[ns] = NULL; statp->_u._ext.nsaddrs[ns] = NULL;
} }
} }
@ -114,11 +110,11 @@ Index: glibc-2.23-131-ga603305/resolv/res_init.c
} }
libc_hidden_def (__res_iclose) libc_hidden_def (__res_iclose)